@@ -1,10 +1,18 @@
-# -*- coding: utf-8 -*-
+# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #
 # Copyright 2013 Canonical
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
 # by the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 from __future__ import absolute_import
 
@@ -55,6 +63,12 @@ class TestAddressBarSelection(StartOpenRemotePageTestCaseBase):
         self.main_window.open_toolbar()
         address_bar = self.main_window.get_address_bar()
         self.pointing_device.click_object(address_bar)
+        self.assert_osk_eventually_shown()
+        self.pointing_device.click_object(address_bar)
+        # avoid double click
+        time.sleep(1)
+        # now simulate a double click
+        self.pointing_device.click()
         self.pointing_device.click()
         text_field = self.main_window.get_address_bar_text_field()
         self.assertThat(lambda: len(text_field.selectedText),
