@@ -1,36 +1,52 @@
-# -*- coding: utf-8 -*-
+# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #
 # Copyright 2013 Canonical
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
 # by the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 from __future__ import absolute_import
 
 from testtools.matchers import Equals
 from autopilot.matchers import Eventually
 
+import unittest
+
 from webbrowser_app.tests import \
-    BrowserTestCaseBaseWithHTTPServer, \
-    StartOpenRemotePageTestCaseBase, \
-    HTTP_SERVER_PORT
+    http_server, \
+    BrowserTestCaseBase, \
+    StartOpenRemotePageTestCaseBase
 
 
 LOREMIPSUM = "<p>Lorem ipsum dolor sit amet.</p>"
 
 
-class TestProgressBarAtStartup(BrowserTestCaseBaseWithHTTPServer):
+class TestProgressBarAtStartup(BrowserTestCaseBase):
 
     """Tests that the progress bar (embedded inside the address bar) is
     initially visible when loading a page."""
 
     def setUp(self):
-        self.base_url = "http://localhost:%d" % HTTP_SERVER_PORT
+        self.server = http_server.HTTPServerInAThread()
+        self.addCleanup(self.server.cleanup)
+        self.base_url = "http://localhost:%d" % self.server.port
+        self.ping_server()
         self.url = self.base_url + "/wait/8"
         self.ARGS = [self.url]
         super(TestProgressBarAtStartup, self).setUp()
 
+    @unittest.skip("This test is flaky on slow configurations where the "
+                   "autopilot machinery takes longer to initialize than the "
+                   "hardcoded page load delay.")
     def test_chrome_initially_shown_then_hides_when_loaded(self):
         self.assert_chrome_eventually_shown()
         self.assert_page_eventually_loaded(self.url)
@@ -44,20 +60,14 @@ class TestProgressBar(StartOpenRemotePageTestCaseBase):
 
     def test_chrome_hides_when_loaded(self):
         self.assert_chrome_eventually_hidden()
-        url = "http://localhost:%d/wait/3" % HTTP_SERVER_PORT
+        url = self.base_url + "/wait/3"
         self.go_to_url(url)
         self.assert_chrome_eventually_shown()
         self.assert_page_eventually_loaded(url)
         self.assert_chrome_eventually_hidden()
 
     def test_load_page_from_link_reveals_chrome(self):
-        # craft a page that accepts clicks anywhere inside its window
-        style = "'margin: 0; height: 100%'"
-        url = "http://localhost:%d/wait/3" % HTTP_SERVER_PORT
-        script = "'window.location = \"%s\"'" % url
-        html = "<html><body style=%s onclick=%s></body></html>" % \
-            (style, script)
-        url = self.make_raw_html_page(html)
+        url = self.base_url + "/clickanywherethenwait/3"
         self.go_to_url(url)
         self.assert_page_eventually_loaded(url)
         self.assert_chrome_eventually_hidden()
@@ -69,7 +79,7 @@ class TestProgressBar(StartOpenRemotePageTestCaseBase):
         # simulate user interaction to hide the chrome while loading,
         # and ensure it doesn’t re-appear when loaded
         self.assert_chrome_eventually_hidden()
-        url = "http://localhost:%d/wait/3" % HTTP_SERVER_PORT
+        url = self.base_url + "/wait/3"
         self.go_to_url(url)
         self.assert_chrome_eventually_shown()
         webview = self.main_window.get_current_webview()
@@ -82,7 +92,7 @@ class TestProgressBar(StartOpenRemotePageTestCaseBase):
         # ensure that the chrome is not automatically hidden
         # when the user interrupts a page that was loading
         self.assert_chrome_eventually_hidden()
-        url = "http://localhost:%d/wait/5" % HTTP_SERVER_PORT
+        url = self.base_url + "/wait/5"
         self.go_to_url(url)
         self.assert_page_eventually_loading()
         self.assert_chrome_eventually_shown()
