@@ -1,15 +1,24 @@
-# -*- coding: utf-8 -*-
+# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #
 # Copyright 2013 Canonical
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
 # by the Free Software Foundation.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 from __future__ import absolute_import
 
 import time
-from testtools.matchers import Equals, Is, Not
+import unittest
+from testtools.matchers import Equals
 from autopilot.matchers import Eventually
 
 from webbrowser_app.tests import StartOpenRemotePageTestCaseBase
@@ -19,22 +28,9 @@ class TestTabs(StartOpenRemotePageTestCaseBase):
 
     """Tests tabs management."""
 
-    def assert_activity_view_eventually_visible(self):
-        self.assertThat(self.main_window.get_activity_view,
-                        Eventually(Not(Is(None))))
-
-    def assert_activity_view_eventually_hidden(self):
-        self.assertThat(self.main_window.get_activity_view,
-                        Eventually(Is(None)))
-
-    def ensure_activity_view_visible(self):
-        self.ensure_chrome_is_hidden()
-        self.main_window.open_toolbar().click_button("activityButton")
-        self.assert_activity_view_eventually_visible()
-
     def open_new_tab(self):
         # assumes the activity view is already visible
-        self.assertIsNotNone(self.main_window.get_activity_view())
+        self.main_window.get_activity_view()
         newtab_delegate = self.main_window.get_tabslist_newtab_delegate()
         # XXX: This assumes the new tab delegate is in sight, which might not
         # always be the case if there is a large number of tabs open. However
@@ -73,7 +69,7 @@ class TestTabs(StartOpenRemotePageTestCaseBase):
         self.assertThat(view.count, Eventually(Equals(1)))
 
     def test_toggle_activity_view(self):
-        self.assertIsNone(self.main_window.get_activity_view())
+        self.assert_activity_view_eventually_hidden()
         self.ensure_activity_view_visible()
         self.assert_chrome_eventually_hidden()
         self.main_window.open_toolbar().click_button("activityButton")
@@ -145,6 +141,8 @@ class TestTabs(StartOpenRemotePageTestCaseBase):
         address_bar = self.main_window.get_address_bar()
         self.assertThat(address_bar.activeFocus, Eventually(Equals(True)))
 
+    # FIXME: re-enable when implemented in oxide
+    @unittest.skip("not implemented in oxide yet")
     def test_open_target_blank_in_new_tab(self):
         url = self.base_url + "/blanktargetlink"
         self.go_to_url(url)
@@ -154,6 +152,8 @@ class TestTabs(StartOpenRemotePageTestCaseBase):
         self.assertThat(self.main_window.currentIndex, Eventually(Equals(1)))
         self.assert_current_url(self.base_url + "/aleaiactaest")
 
+    # FIXME: re-enable when implemented in oxide
+    @unittest.skip("not implemented in oxide yet")
     def test_open_iframe_target_blank_in_new_tab(self):
         url = self.base_url + "/fulliframewithblanktargetlink"
         self.go_to_url(url)
